.. AUTO-GENERATED FILE -- DO NOT EDIT!

core.socket
===========

Module: :mod:`core.socket`
--------------------------
Inheritance diagram for ``zmq.core.socket``:

.. inheritance-diagram:: zmq.core.socket 
   :parts: 3

.. automodule:: zmq.core.socket

.. currentmodule:: zmq.core.socket

:class:`Socket`
---------------


.. autoclass:: Socket
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

